spacepy.pycdf.VarCopy — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »

# spacepy.pycdf.VarCopy

class `spacepy.pycdf.` `VarCopy`

  A list-like copy of the data and attributes in a `Var`

  Data are in the list elements. CDF attributes are in a dict, accessed through `attrs`. (I.e., data and attributes are accessed like in a `Var`.)

  Do not instantiate this class directly; use `copy()` on an existing `Var`.

  `attrs`

    Python dictionary containing attributes copied from the zVar

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- pycdf - Python interface to CDF files »